## ctcsound
Python bindings for Csound using ctypes. Can be used from python2.x and python3.x as well.  

This repository is closely tied to the develop branch of Csound. This means that if you're
using a precompiled release of Csound, you should better use the *ctcsound.py* file shipped with
that release to avoid binding errors with libcsound.

Dependency: numpy, Csound 6.07 or higher.
